@@ -131,6 +131,10 @@ struct http *http_new(void)
 	curl_easy_setopt(h->curl, CURLOPT_NOSIGNAL, 1L);
 	curl_easy_setopt(h->curl, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
 
+	curl_easy_setopt(h->curl, CURLOPT_TCP_KEEPALIVE, 1L);
+	curl_easy_setopt(h->curl, CURLOPT_TCP_KEEPIDLE, 120L);
+	curl_easy_setopt(h->curl, CURLOPT_TCP_KEEPINTVL, 60L);
+
 	h->headers = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
 	// set default headers
@@ -190,7 +194,7 @@ void http_set_content_length(struct http *h, goffset len)
 	g_free(tmp);
 }
 
-static int curl_progress(struct http *h, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow)
+static int curl_progress(struct http *h, double dltotal, double dlnow, double ultotal, double ulnow)
 {
 	if (h->progress_cb) {
 		if (!h->progress_cb(dltotal, dlnow, ultotal, ulnow, h->progress_data))
@@ -220,8 +224,8 @@ void http_set_progress_callback(struct http *h, http_progress_fn cb, gpointer da
 		h->progress_data = data;
 
 		curl_easy_setopt(h->curl, CURLOPT_NOPROGRESS, 0L);
-		curl_easy_setopt(h->curl, CURLOPT_XFERINFOFUNCTION, curl_progress);
-		curl_easy_setopt(h->curl, CURLOPT_XFERINFODATA, h);
+		curl_easy_setopt(h->curl, CURLOPT_PROGRESSFUNCTION, (curl_progress_callback)curl_progress);
+		curl_easy_setopt(h->curl, CURLOPT_PROGRESSDATA, h);
 	} else {
 		curl_easy_setopt(h->curl, CURLOPT_NOPROGRESS, 1L);
 	}
